#
# spec file for package bolt
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _hardened_build 1
Name:           bolt
Version:        0.9.1
Release:        150400.1.11
Summary:        Thunderbolt 3 device manager
License:        GPL-2.0-or-later
Group:          System/Daemons
URL:            https://gitlab.freedesktop.org/bolt/bolt
Source0:        https://gitlab.freedesktop.org/bolt/bolt/-/archive/%{version}/bolt-%{version}.tar.bz2
BuildRequires:  glib2-devel
BuildRequires:  glibc-devel >= 2.27
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  polkit-devel
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(udev)

%description
Userspace system daemon to enable security levels for Thunderbolt 3
on GNU/Linux.

%package        tools
Summary:        Bolt Tools
Group:          System/Management
Requires:       %{name} = %{version}-%{release}

%description    tools
The %{name}-tools package contains optional tools from the Bolt
software framework.

%prep
%setup -q -n bolt-%{version}

%build
%meson
%meson_build

%check
%meson_test

%install
%meson_install

mkdir -p %{buildroot}/%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}/%{_sbindir}/rcbolt

# move polkit rules to doc folder: the wheel group does not have special
# meaning on SUSE based distros
mkdir -p %{buildroot}/%{_docdir}/bolt/
mv %{buildroot}/usr/share/polkit-1/rules.d/org.freedesktop.bolt.rules %{buildroot}/%{_docdir}/bolt/

%preun
%service_del_preun bolt.service

%post
%service_add_post bolt.service

%postun
%service_del_postun bolt.service

%pre
%service_add_pre bolt.service

%files
%doc README.md INSTALL.md BUGS.md
%license COPYING
%{_libexecdir}/boltd
%{_unitdir}/bolt.service
%{_sbindir}/rcbolt
%{_datadir}/dbus-1/system.d/org.freedesktop.bolt.conf
%{_datadir}/polkit-1/actions/org.freedesktop.bolt.policy
%{_udevrulesdir}/90-bolt.rules
%{_datadir}/dbus-1/interfaces/org.freedesktop.bolt.xml
%{_datadir}/dbus-1/system-services/org.freedesktop.bolt.service
%{_docdir}/bolt/org.freedesktop.bolt.rules

%files tools
%{_bindir}/boltctl

%changelog
* Tue Sep 28 2021 oneukum@suse.com
- Need in SLE
  * Support for working with adapters without ROMs is needed
    (jsc#SLE-19359)
* Wed Jun  2 2021 rpm@fthiessen.de
- Update to 0.9.1
  * Support Ice Lake Thunderbolt 3 i/o subsystem
  * Don't store domains where uuids change across reboots
  * Fixes for the journal and the domain's acl-log
  * Version the store and use that to clean up stale domains once
  * Host identification for embedded thunderbolt controllers [!233]
  * Various other small bug fixes and memory leak fixes.
* Tue Jun 16 2020 rfrohl@suse.com
- Update to 0.9
  * New Features:
  - Add 'Generation' attribute for the Manager
  - Ability to change the policy of a stored device
  - The BootACL Domain property is now writable
  - Support for systemd's service watchdog
  - Expose Link Speed sysfs attributes
  * Improvements:
  - boltclt: show timestamps in 'monitor' call
  - Persist the host device
  * Bug fixes:
  - Plug small memory leaks in error conditions
  - Ignore spurious wakeup device uevents for probing
  - Preserve keystate when updating devices
* Tue Dec 24 2019 dimstar@opensuse.org
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut though the -mini flavors (complete previos change).
* Thu Dec 19 2019 dimstar@opensuse.org
- BuildRequire pkgconfig(libudev) instead of libudev-devel:
  Allow OBS to shortcut through the -mini flavors.
* Sun Jun 16 2019 rfrohl@suse.com
- Update to 0.8
  * New Features:
  - IOMMU support: adapt behavior iommu support is present and active
  * automatically enroll new devices with the new iommu policy when iommu is active
  * automatically authorize devices with the iommu policy if iommu is active
  - boltctl config command to describe, get and set global, device and domain properties.
  - Chain authorization and enrollment via boltctl {enroll, authorize} --chain
  - bolt-mock script for interactively testing boltd
  * Improvements:
  - Automatically import devices that were authorized at boot
  - Make tests installable
  - Honour STATE_DIRECTORY and RUNTIME_DIRECTORY
  - Profiling support via gprof
  * Bug fixes:
  - Better handling of random data generation, removed hardening_for_RNG_code.patch
  - Fix double free in case of client creation failure
  - Fix invalid format string in warning
  - dbus configuration moved /usr/share
* Fri Feb 22 2019 rfrohl@suse.com
- Move polkit rules file to into doc folder. The 'wheel' group has no special
  privileges and the file did not have any effect. (boo#1125425)
* Mon Jan  7 2019 rfrohl@suse.com
- use meson macros during build
* Mon Jan  7 2019 rfrohl@suse.com
- Update to 0.7
  * Features:
  - announce status to systemd via sd_notify (using a simple custom implementation)
  * Bug fixes:
  - properly update global security level status
  - adapt to systemd 240 not sending bind/unbind uevents
  - fix compilation on musl
  - daemon: use g_unix_signal_source… to catch signals
  * Improvements
  - precondition checks cleanup and completion
  - error cleanup
  - fix some leaks and issues uncovered by coverity
* Fri Jan  4 2019 rfrohl@suse.com
- security review: add RNG hardening patch (boo#1119975):
  hardening_for_RNG_code.patch
* Mon Dec 10 2018 rfrohl@suse.com
  Update to 0.6
- New Features:
  * pre-boot access control list, aka. BootACL support
  - domains objects are now persistent
  * new Uid (dbus) / uid (object) property derived from the uuid of the device representing the root switch
  * sysfs and id attribute will be set/unset on connects and disconnects
  * domains are now stored in the boltd database
  - domains got the BootACL (dbus) / bootacl (object) property
  * uuids can be added, removed or set in batch
  * when domain is online: changes are written to the sysfs boot_acl attribute directly
  * when domain is offline: changes are written to a journal and then reapplied in order when the domain is connected
  - newly enrolled devices get added to all bootacls of all domains if the policy is BOLT_POLICY_AUTO
  - removed devices get deleted from all bootacls of all domains
  - boltacl domain command will show the bootacl slots and their content
  * boltctl gained the -U, --uuid option, to control how uuids are printed
- Improvements and fixes:
  * Testing
  - boltctl is now included in the tests
  * Bugs and robustness:
  - The device state is verified in Device.Authorize
  - Handle empty 'keys' sysfs device attribute
  - Properly adjust policies when enrolling already authorized devices
  - Fix potential crasher when logging assertions g_return_if_fail
